require 'yaml'
require 'sipo_mailer/utils/hash_extensions'

module SipoMailer
  class Config
    class ConfigMissing < StandardError; end

    using HashExtensions

    attr_accessor :yaml

    def initialize
      Installer.install unless File.exist? Installer.config
      load_yaml
      check_config
      mailer_init
    end

    private

    def check_config
      raise ConfigMissing, 'address_book' unless yaml[:address_book]
      raise ConfigMissing, 'email: address' unless yaml.dig(:email, :address)
      raise ConfigMissing, 'email: password' unless yaml.dig(:email, :password)
    rescue ConfigMissing => e
      puts "V konfiguraci není vyplěna hodnota '#{e.message}'. Umístění konfigurace: #{SipoMailer::Installer.config}"
      exit
    end

    def load_yaml
      self.yaml = YAML.load_file(Installer.config).symbolize_keys
    end

    def mailer_init
      options = email_options
      Mail.defaults { delivery_method :smtp, options }
    end

    def email_options
      {
        address:              'smtp.gmail.com',
        port:                  587,
        domain:               'gmail.com',
        user_name:            'givit.cz@gmail.com',
        password:             yaml.dig(:email, :password),
        authentication:       :login,
        enable_starttls_auto: true
      }
    end
  end
end
