module SipoMailer
  module Installer
    DEFAULT_DIR = 'sipo_mailer'.freeze
    CONFIG_FILE = 'config.yml'

    class << self
      def install
        create_dir
        copy_files
      end

      def create_dir
        result = Dir.mkdir(config_dir) unless Dir.exist?(config_dir)
        result == 0
      end

      def copy_files
        copy_file(config_example, CONFIG_FILE)
        copy_file(book_example, 'adresar.csv')
      end

      def copy_file(src, dest)
        return false if File.exist? dest
        File.open("#{config_dir}/#{dest}", 'w') do |file|
          source = File.open(src)
          file.write(source.readlines.join(''))
          source.close
        end
        true
      end

      def config_example
        example_path = Gem.bin_path('sipo_mailer', 'mailer').split('/')[0..-3]
        [example_path, 'config', "#{CONFIG_FILE}.example"].join('/')
      end

      def book_example
        example_path = Gem.bin_path('sipo_mailer', 'mailer').split('/')[0..-3]
        [example_path, 'config', 'adresar.csv.example'].join('/')
      end

      def config
        [config_dir, CONFIG_FILE].join('/')
      end

      def config_dir
        case os
        when :windows
          [ENV['HOME'], DEFAULT_DIR].join('/')
        else
          [ENV['USERPROFILE'], DEFAULT_DIR].join('/')
        end
      end

      def os
        host_os = RbConfig::CONFIG['host_os']
        case host_os
        when /mswin|msys|mingw|cygwin|bccwin|wince|emc/
          :windows
        when /darwin|mac os/
          :macosx
        when /linux/
          :linux
        when /solaris|bsd/
          :unix
        else
          raise Error::WebDriverError, "unknown os: #{host_os.inspect}"
        end
      end
    end
  end
end
